@@ -7,6 +7,9 @@ from acido.azure_utils.ManagedIdentity import ManagedAuthentication, Resources
 from huepy import *
 import os
 
+__authors__ = "Juan Ramón Higueras Pica (juanramon.higueras@wsg127.com)"
+__coauthor__ = "Xavier Álvarez Delgado (xalvarez@merabytes.com)"
+
 class BlobManager(ManagedAuthentication):
     service_client = None
     container_client = None
